@@ -1,6 +1,5 @@
 import asyncio
-import re
-from typing import TYPE_CHECKING, Optional, TypeVar, Union
+from typing import TYPE_CHECKING, Literal, Optional, TypeVar, Union, overload
 
 from pydoll.commands import (
     DomCommands,
@@ -45,6 +44,76 @@ class FindElementsMixin:
     complex location logic themselves.
     """
 
+    @overload
+    async def find(
+        self,
+        id: Optional[str] = ...,
+        class_name: Optional[str] = ...,
+        name: Optional[str] = ...,
+        tag_name: Optional[str] = ...,
+        text: Optional[str] = ...,
+        timeout: int = ...,
+        find_all: Literal[False] = False,
+        raise_exc: Literal[True] = True,
+        **attributes: dict[str, str],
+    ) -> 'WebElement': ...
+
+    @overload
+    async def find(
+        self,
+        id: Optional[str] = ...,
+        class_name: Optional[str] = ...,
+        name: Optional[str] = ...,
+        tag_name: Optional[str] = ...,
+        text: Optional[str] = ...,
+        timeout: int = ...,
+        find_all: Literal[True] = True,
+        raise_exc: Literal[True] = True,
+        **attributes: dict[str, str],
+    ) -> list['WebElement']: ...
+
+    @overload
+    async def find(
+        self,
+        id: Optional[str] = ...,
+        class_name: Optional[str] = ...,
+        name: Optional[str] = ...,
+        tag_name: Optional[str] = ...,
+        text: Optional[str] = ...,
+        timeout: int = ...,
+        find_all: Literal[True] = True,
+        raise_exc: Literal[False] = False,
+        **attributes: dict[str, str],
+    ) -> Optional[list['WebElement']]: ...
+
+    @overload
+    async def find(
+        self,
+        id: Optional[str] = ...,
+        class_name: Optional[str] = ...,
+        name: Optional[str] = ...,
+        tag_name: Optional[str] = ...,
+        text: Optional[str] = ...,
+        timeout: int = ...,
+        find_all: Literal[False] = False,
+        raise_exc: Literal[False] = False,
+        **attributes: dict[str, str],
+    ) -> Optional['WebElement']: ...
+
+    @overload
+    async def find(
+        self,
+        id: Optional[str] = ...,
+        class_name: Optional[str] = ...,
+        name: Optional[str] = ...,
+        tag_name: Optional[str] = ...,
+        text: Optional[str] = ...,
+        timeout: int = ...,
+        find_all: bool = ...,
+        raise_exc: bool = ...,
+        **attributes: dict[str, str],
+    ) -> Union['WebElement', list['WebElement'], None]: ...
+
     async def find(  # noqa: PLR0913, PLR0917
         self,
         id: Optional[str] = None,
@@ -102,6 +171,51 @@ class FindElementsMixin:
             by, value, timeout=timeout, find_all=find_all, raise_exc=raise_exc
         )
 
+    @overload
+    async def query(
+        self,
+        expression: str,
+        timeout: int = ...,
+        find_all: Literal[False] = False,
+        raise_exc: Literal[True] = True,
+    ) -> 'WebElement': ...
+
+    @overload
+    async def query(
+        self,
+        expression: str,
+        timeout: int = ...,
+        find_all: Literal[False] = False,
+        raise_exc: Literal[False] = False,
+    ) -> Optional['WebElement']: ...
+
+    @overload
+    async def query(
+        self,
+        expression: str,
+        timeout: int = ...,
+        find_all: Literal[True] = True,
+        raise_exc: Literal[True] = True,
+    ) -> list['WebElement']: ...
+
+    @overload
+    async def query(
+        self,
+        expression: str,
+        timeout: int = ...,
+        find_all: Literal[True] = True,
+        raise_exc: Literal[False] = False,
+    ) -> Optional[list['WebElement']]: ...
+
+    @overload
+    async def query(
+        self,
+        expression: str,
+        timeout: int = ...,
+        find_all: bool = ...,
+        raise_exc: bool = ...,
+    ) -> Union['WebElement', list['WebElement'], None]: ...
+
     async def query(
         self, expression: str, timeout: int = 0, find_all: bool = False, raise_exc: bool = True
     ) -> Union['WebElement', list['WebElement'], None]:
@@ -206,18 +320,13 @@ class FindElementsMixin:
             EvaluateResponse, CallFunctionOnResponse
         ] = await self._execute_command(command)
 
-        if not response_for_command.get('result', {}).get('result', {}).get('objectId'):
+        if not self._has_object_id_key(response_for_command):
             if raise_exc:
                 raise ElementNotFound()
             return None
 
         object_id = response_for_command['result']['result']['objectId']
-        node_description = await self._describe_node(object_id=object_id)
-        attributes = node_description.get('attributes', [])
-
-        tag_name = node_description.get('nodeName', '').lower()
-        attributes.extend(['tag_name', tag_name])
-
+        attributes = await self._get_object_attributes(object_id=object_id)
         return create_web_element(object_id, self._connection_handler, by, value, attributes)  # type: ignore
 
     async def _find_elements(
@@ -281,6 +390,16 @@ class FindElementsMixin:
             )
         return elements
 
+    async def _get_object_attributes(self, object_id: str) -> list[str]:
+        """
+        Get attributes of a DOM node.
+        """
+        node_description = await self._describe_node(object_id=object_id)
+        attributes = node_description.get('attributes', [])
+        tag_name = node_description.get('nodeName', '').lower()
+        attributes.extend(['tag_name', tag_name])
+        return attributes
+
     def _get_by_and_value(  # noqa: PLR0913, PLR0917
         self,
         by_map: dict[str, By],
@@ -352,18 +471,11 @@ class FindElementsMixin:
         Auto-detect selector type from expression syntax.
 
         Patterns:
-        - XPath: starts with //, .// , ./, or /
-        - ID: starts with #
-        - Class: starts with . (but not ./)
+        - XPath: starts with ./, or /
         - Default: CSS_SELECTOR
         """
-        xpath_pattern = r'^(//|\.//|\.\/|/)'
-        if re.match(xpath_pattern, expression):
+        if expression.startswith('./') or expression.startswith('/'):
             return By.XPATH
-        if expression.startswith('#'):
-            return By.ID
-        if expression.startswith('.') and not expression.startswith('./'):
-            return By.CLASS_NAME
 
         return By.CSS_SELECTOR
 
@@ -435,7 +547,7 @@ class FindElementsMixin:
             case _:
                 selector = escaped_value
         if object_id and not by == By.XPATH:
-            script = Scripts.RELATIVE_QUERY_SELECTOR_ALL.replace('{selector}', escaped_value)
+            script = Scripts.RELATIVE_QUERY_SELECTOR_ALL.replace('{selector}', selector)
             command = RuntimeCommands.call_function_on(
                 function_declaration=script,
                 object_id=object_id,
@@ -499,3 +611,10 @@ class FindElementsMixin:
         Converts absolute XPath to relative for context-based searches.
         """
         return f'.{xpath}' if not xpath.startswith('.') else xpath
+
+    @staticmethod
+    def _has_object_id_key(response: Union[EvaluateResponse, CallFunctionOnResponse]) -> bool:
+        """
+        Check if response has objectId key.
+        """
+        return bool(response.get('result', {}).get('result', {}).get('objectId'))
