@@ -233,3 +233,27 @@ class IFrameNotFound(PydollException):
     """Raised when an iframe is not found."""
 
     message = 'The iframe was not found'
+
+
+class NetworkEventsNotEnabled(PydollException):
+    """Raised when network events are not enabled."""
+
+    message = 'Network events not enabled'
+
+
+class ScriptException(PydollException):
+    """Base class for exceptions related to JavaScript execution."""
+
+    message = 'A script execution error occurred'
+
+
+class InvalidScriptWithElement(ScriptException):
+    """Raised when a script contains 'argument' but no element is provided."""
+
+    message = 'Script contains "argument" but no element was provided'
+
+
+class WrongPrefsDict(PydollException):
+    """Raised when the prefs dict provided contains the 'prefs' key"""
+
+    message = 'The dict can not contain "prefs" key, provide only the prefs options'
